@@ -23,7 +23,7 @@ QueueView::QueueView(Spotify::Session* pSession, QWidget* parent)
 
 
     //define slider used for displaying buffering and track progress
-    m_pProgressSlider = new CustomSlider(this,355,40);
+    m_pProgressSlider = new CustomSlider(this,SLIDER_WIDTH,SLIDER_HEIGHT);
     m_pProgressSlider->setBgColor(QColor(51,51,51)); //background color of progress slider
     m_pProgressSlider->setP1Color(QColor(8,117,189)); //color of buffering progress bar
     m_pProgressSlider->setP2Color(QColor(41,166,241)); //color of track progress bar
@@ -34,12 +34,13 @@ QueueView::QueueView(Spotify::Session* pSession, QWidget* parent)
     m_pSpectrum = new SpectrumAnalyzer(this,50,40);
     m_pSpectrum->setColor(QColor(255,255,255)); //set spectrum color to white
 
-    //init the trackinfo listview instance
+    //init the trackinfo listview instance and associated item delegate
     m_pTrackInfoView = new QListView(this);
     m_pTrackInfoModel = new QStandardItemModel(this);
     m_pTrackInfoDelegate = new ListViewDelegate(this);
     m_pTrackInfoDelegate->setHeaderFontPointSize(15);
     m_pTrackInfoDelegate->setSubHeaderFontPointSize(14);
+    m_pTrackInfoDelegate->setItemTextHighlightColor(QColor(41,166,241));
 
     m_pTrackInfoView->setItemDelegate(m_pTrackInfoDelegate); //connect the delegate to view
     m_pTrackInfoView->setModel(m_pTrackInfoModel); //connect the model to view
@@ -149,6 +150,11 @@ void QueueView::setNowPlaying(QList<Spotify::Track*> queue, int currQueuePos, bo
 
               //m_TrackInfo.setCurrentRow(m_currQueuePos);
               QModelIndex index = m_pTrackInfoModel->index(m_currQueuePos,0);
+
+              QStandardItem* currTrackItem = m_pTrackInfoModel->itemFromIndex(index);
+              if(currTrackItem)
+                  currTrackItem->setData(true,ListViewDelegate::highlightItemTextRole); //highlight text of current track item
+
               if(index.isValid())
                 m_pTrackInfoView->setCurrentIndex(index);
 
@@ -237,7 +243,7 @@ void QueueView::OnBufferNextTrack()
                 error = m_pSession->play(track,true); //initiate buffering of track
                 if(error.isError())
                 {
-                    qDebug()<< "Error starting track playback: " << error.toString();
+                    QMaemo5InformationBox::information(this,tr("Error starting track playback: ") + error.toString());
                 }
                 m_UpdateBufPos = false; //do not update the buffering position (current track still playing)
             }
@@ -317,11 +323,16 @@ void QueueView::OnTrackActivated(QModelIndex index)
     //A track has been activated (e.g., selected) in the track list
     //Display artist and album cover pic (if available)
 
-    Q_UNUSED(index);
+        Spotify::Error error;
 
-    Spotify::Error error;
+        QStandardItem* prevTrackItem = m_pTrackInfoModel->item(m_currQueuePos); //get previously selected item
+        if(prevTrackItem)
+            prevTrackItem->setData(false,ListViewDelegate::highlightItemTextRole); //remove highlight from prev. selected item
 
-        m_currQueuePos = m_pTrackInfoView->currentIndex().row();
+        QStandardItem* currTrackItem = m_pTrackInfoModel->itemFromIndex(index); //highlight new item text
+        currTrackItem->setData(true,ListViewDelegate::highlightItemTextRole);
+
+        m_currQueuePos = index.row(); //get corresponding position in playqueue
 
         m_pCurrTrack = m_PlayQueue.at(m_currQueuePos);
 
@@ -334,6 +345,7 @@ void QueueView::OnTrackActivated(QModelIndex index)
             m_pProgressSlider->setPos2(0);
             setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
             QMaemo5InformationBox::information(this,tr("Buffering"));
+            m_UpdateBufPos = true; //allow update of buffering state
             error = m_pSession->play(m_pCurrTrack); //request to start playback of track
             //emit playing();
             if(error.isError())
@@ -356,7 +368,7 @@ void QueueView::OnTrackPosUpdated(qint64 trackPos)
 
     if(m_Active && m_UpdateBufPos)
     {
-        int currPos = (trackPos*355) / (m_currTrackDuration*1000);
+        int currPos = (trackPos*SLIDER_WIDTH) / (m_currTrackDuration*1000);
         m_pProgressSlider->setPos1(currPos); //set curr. slider position
     }
 
@@ -389,7 +401,7 @@ void QueueView::OnPlaybackPositionUpdated(qint64 trackPos)
                 m_pProgressSlider->setText(strCurrTrackProgressInfo);
         }
 
-        int currPos = (trackPos*355) / (m_currTrackDuration*1000);
+        int currPos = (trackPos*SLIDER_WIDTH) / (m_currTrackDuration*1000);
 
         m_pProgressSlider->setPos2(currPos); //set curr. slider position
     }
@@ -405,6 +417,21 @@ void QueueView::OnPauseResumeToggle()
     }
 }
 
+void QueueView::setUpdateBufferPos(bool update)
+{
+    //public method for setting the state of buffer progress updating
+    m_UpdateBufPos = update;
+    if(!update)
+    { //set the buffer progress to progress indicator end position (current track has been completely buffered)
+        m_pProgressSlider->setPos1(SLIDER_WIDTH);
+    }
+}
+
+bool QueueView::getUpdateBufferPos()
+{
+    return m_UpdateBufPos;
+}
+
 void QueueView::setActive(bool active, bool shuffleActive)
 {
     //set whether the current instance is active (i.e., whether signals should be processed),
@@ -437,6 +464,8 @@ void QueueView::OnNextTrackBtn()
 
     Spotify::Error error;
 
+    qint32 oldQueuePos = m_currQueuePos;
+
     if(m_Shuffle)
     { //shuffle mode active, get position of next track to play from shuffle queue
         if(m_currShufflePos < m_ShuffleQueue.size()-1)
@@ -454,6 +483,11 @@ void QueueView::OnNextTrackBtn()
     {
         if(!m_Shuffle)
             m_currQueuePos++;
+        QStandardItem* prevTrackItem = m_pTrackInfoModel->item(oldQueuePos); //get previously selected item
+        if(prevTrackItem)
+            prevTrackItem->setData(false,ListViewDelegate::highlightItemTextRole); //remove highlight from prev. selected item
+        QStandardItem* currTrackItem = m_pTrackInfoModel->item(m_currQueuePos);
+        currTrackItem->setData(true,ListViewDelegate::highlightItemTextRole); //highlight new item text
         m_pCurrTrack = m_PlayQueue.at(m_currQueuePos);
         if(m_pCurrTrack)
         {
@@ -468,10 +502,11 @@ void QueueView::OnNextTrackBtn()
             m_PauseResumeBtn.setChecked(true); //toggle playing state
             setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
             QMaemo5InformationBox::information(this,tr("Buffering"));
+            m_UpdateBufPos = true; //allow update of buffering state
             error = m_pSession->play(m_pCurrTrack); //initiate track playback
             if(error.isError())
             {
-                qDebug()<< "Error starting track playback: " << error.toString();
+                QMaemo5InformationBox::information(this,tr("Error starting track playback: ") + error.toString());
             }
             setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
             emit playQueuePosUpdated(m_currQueuePos,m_currShufflePos); //emit pos updated
@@ -485,6 +520,8 @@ void QueueView::OnPrevTrackBtn()
 
     Spotify::Error error;
 
+    qint32 oldQueuePos = m_currQueuePos;
+
     if(m_Shuffle)
     { //shuffle mode active, get position of next track to play from shuffle queue
         if(m_currShufflePos > 0)
@@ -502,6 +539,11 @@ void QueueView::OnPrevTrackBtn()
     {
         if(!m_Shuffle)
             m_currQueuePos--;
+        QStandardItem* prevTrackItem = m_pTrackInfoModel->item(oldQueuePos); //get previously selected item
+        if(prevTrackItem)
+            prevTrackItem->setData(false,ListViewDelegate::highlightItemTextRole); //remove highlight from prev. selected item
+        QStandardItem* currTrackItem = m_pTrackInfoModel->item(m_currQueuePos);
+        currTrackItem->setData(true,ListViewDelegate::highlightItemTextRole); //highlight new item text
         m_pCurrTrack = m_PlayQueue.at(m_currQueuePos);
         if(m_pCurrTrack)
         {
@@ -516,10 +558,11 @@ void QueueView::OnPrevTrackBtn()
             m_PauseResumeBtn.setChecked(true); //toggle playing state
             setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
             QMaemo5InformationBox::information(this,tr("Buffering"));
+            m_UpdateBufPos = true; //allow update of buffering state
             error = m_pSession->play(m_pCurrTrack); //initiate track playback
             if(error.isError())
             {
-                qDebug()<< "Error starting track playback: " << error.toString();
+                QMaemo5InformationBox::information(this,tr("Error starting track playback: ") + error.toString());
             }
              setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
             emit playQueuePosUpdated(m_currQueuePos,m_currShufflePos); //emit pos updated
@@ -538,6 +581,8 @@ void QueueView::OnTrackPlaybackFinished()
 
         Spotify::Error error;
 
+        qint32 oldQueuePos = m_currQueuePos;
+
         if(m_Shuffle)
         { //shuffle mode active, get position of next track to play from shuffle queue
             if(m_currShufflePos<m_ShuffleQueue.size()-1)
@@ -555,6 +600,11 @@ void QueueView::OnTrackPlaybackFinished()
         {
             if(!m_Shuffle) //normal playback mode
                 m_currQueuePos++;
+            QStandardItem* prevTrackItem = m_pTrackInfoModel->item(oldQueuePos); //get previously selected item
+            if(prevTrackItem)
+                prevTrackItem->setData(false,ListViewDelegate::highlightItemTextRole); //remove highlight from prev. selected item
+            QStandardItem* currTrackItem = m_pTrackInfoModel->item(m_currQueuePos);
+            currTrackItem->setData(true,ListViewDelegate::highlightItemTextRole); //highlight new item text
             m_pCurrTrack = m_PlayQueue.at(m_currQueuePos);
             if(m_pCurrTrack)
             {
@@ -570,7 +620,7 @@ void QueueView::OnTrackPlaybackFinished()
                     error = m_pSession->play(m_pCurrTrack); //initiate track playback
                     if(error.isError())
                     {
-                        qDebug()<< "Error starting track playback: " << error.toString();
+                        QMaemo5InformationBox::information(this,tr("Error starting track playback: ") + error.toString());
                     }
                 }
                 else
@@ -640,3 +690,18 @@ void QueueView::shuffleQueue()
 
     m_currShufflePos = -1;
 }
+
+void QueueView::keyPressEvent(QKeyEvent *evt)
+{
+    //Overriden keyPressEvent handler
+
+    if(evt->key()==Qt::Key_Left)
+    {
+        close(); //close the view
+        evt->accept();
+    }
+    else
+    {
+        QMainWindow::keyPressEvent(evt);
+    }
+}
