@@ -18,6 +18,7 @@
 #include <QDebug>
 #include <QScrollBar>
 #include <QTextStream>
+#include <QKeyEvent>
 #include <QtGui/QPixmap>
 #include <QMaemo5InformationBox>
 #include <qspotify_src/spotifysession.h>
@@ -25,6 +26,11 @@
 #include "SpectrumAnalyzer.h"
 #include "ListViewDelegate.h"
 
+//defines
+
+#define SLIDER_WIDTH 355 //width of the custom progress slider widget
+#define SLIDER_HEIGHT 40 //height of the custom progress slider widget
+
 class QueueView : public QMainWindow
 {
     Q_OBJECT
@@ -38,8 +44,16 @@ public:
 
     void setActive(bool active, bool shuffleActive=false); //set whether the current instance is active (i.e., whether signals should be processed)
 
+    void setUpdateBufferPos(bool update);
+
     bool getShuffleActive();
 
+    bool getUpdateBufferPos();
+
+protected:
+
+    void keyPressEvent(QKeyEvent *evt);
+
 private:
 
     QWidget m_MainLayout;
