@@ -17,10 +17,12 @@
 #include <QtGui/QLabel>
 #include <QtGui/QLineEdit>
 #include <QtGui/QPushButton>
+#include <QtGui/QKeyEvent>
 #include <QtGui/QCloseEvent>
 #include <QSettings>
 #include <QMessageBox>
 #include <QFont>
+#include <QTimer>
 #include <QtMaemo5/QMaemo5InformationBox>
 #include <qspotify_src/spotifysession.h>
 #include "logindialog.h"
@@ -30,6 +32,11 @@
 #include "SpectrumAnalyzer.h"
 #include "customlabel.h"
 
+
+//defines
+
+#define PLAYLIST_LOADING_TIMEOUT  30 //timeout before giving up on waiting for playlists to load (in seconds)
+
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
@@ -39,6 +46,10 @@ public:
     MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
+protected:
+
+    void keyPressEvent(QKeyEvent *evt);
+
 private:
 
     QSettings* m_pAppSettings; //application settings instance
@@ -99,6 +110,10 @@ private:
 
     QMessageBox m_AboutDlg; //App About dialog instance
 
+    QTimer *m_pTimeoutTimer; //timer used for detecting timeouts (i.e., during playlist loading)
+
+    bool m_AudioInit; //TRUE in case audio playback thread initialised
+
 
 private slots:
 
@@ -119,6 +134,7 @@ private slots:
      void OnPlaybackTokenLost();
      void OnActiveQueueViewChanged(bool active, bool shuffleActive);
      void OnSettingsSaved();
+     void OnPlaylistLoadingTimeout();
 
 signals:
 
