@@ -90,7 +90,6 @@ void PlaybackThread::run()
             {
                 if(m_trackStartPosList.first()==0)
                 {
-                   // m_nextTrackStartPos=-1;
                     m_trackStartPosList.removeFirst();
                     emit playbackFinished(); //playback of the current track has finished
                 }
@@ -159,7 +158,6 @@ void PlaybackThread::FIFOAppend(const QByteArray& buffer)
 void PlaybackThread::clearFIFO()
 {
     m_FIFO.clear();
-    qDebug() << "Size of fifo:" << m_FIFO.size();
 }
 
 qint32 PlaybackThread::getFIFOSize()
@@ -221,9 +219,13 @@ void PlaybackThread::setNextTrackStartPos()
 
 void PlaybackThread::setNextTrackStartPos(qint32 pos)
 {
-    //overriden method
-    //m_nextTrackStartPos = pos;
-    m_trackStartPosList.append(pos);
+    //Overriden method.
+    //Assigns the starting position of new track audio data in the buffer.
+    //If the pos param is -1, the list is cleared.
+    if(pos!=-1)
+        m_trackStartPosList.append(pos);
+    else
+        m_trackStartPosList.clear();
 }
 
 void PlaybackThread::setNewTrackStarted(bool started)
