@@ -60,6 +60,8 @@ Spotify::Session::Session( QObject* parent ):
     m_pAudioThread = NULL;
 
     m_preBufActive = true;
+
+    m_bPlaylistsLoading = false;
 }
 
 void Spotify::Session::init()
@@ -84,21 +86,36 @@ void Spotify::Session::init()
     m_ProcessEvents = false; //event processing not initiated
     m_DisableNotifyThread = false;
 
-   m_pAudioThread = new PlaybackThread(this);
+   m_pProcEvtTimer = new QTimer(this);
+   connect(m_pProcEvtTimer,SIGNAL(timeout()),this,SLOT(OnProcessThreadEvents()));
+}
 
-   m_pAudioThread->setBufferingPaused(false);
-   m_pAudioThread->setPlaybackPaused(false);
+void Spotify::Session::initAudio()
+{
+    //Init the audio / playback thread (pulseaudio).
+    //Note: Must be called before calling any Spotify session player functions.
+
+    m_pAudioThread = new PlaybackThread(this);
+
+    m_pAudioThread->setBufferingPaused(false);
+    m_pAudioThread->setPlaybackPaused(false);
 
     connect(m_pAudioThread, SIGNAL(resumeBuffering()),
-                    this, SLOT(OnResumeBuffering()),Qt::QueuedConnection);
+                     this, SLOT(OnResumeBuffering()),Qt::QueuedConnection);
     connect(m_pAudioThread, SIGNAL(playbackPositionUpdated(qint64)),
-                    this, SLOT(OnPlaybackPositionUpdated(qint64)),Qt::QueuedConnection);
+                     this, SLOT(OnPlaybackPositionUpdated(qint64)),Qt::QueuedConnection);
     connect(m_pAudioThread, SIGNAL(playbackFinished()),
-                    this, SLOT(OnPlaybackFinished()),Qt::QueuedConnection);
+                     this, SLOT(OnPlaybackFinished()),Qt::QueuedConnection);
     connect(m_pAudioThread, SIGNAL(playing(bool)),
-                    this, SLOT(OnPlayingState(bool)),Qt::QueuedConnection);
+                     this, SLOT(OnPlayingState(bool)),Qt::QueuedConnection);
 
-   m_pAudioThread->start(); //start audio playback thread
+    m_pAudioThread->start(); //start audio playback thread
+}
+
+bool Spotify::Session::playlistLoadingInProgress()
+{
+    //returns true in case playlist loading (getPlaylists) is currently in progress
+    return m_bPlaylistsLoading;
 }
 
 void Spotify::Session::setMinBufferSize(qint32 secs)
@@ -204,7 +221,8 @@ void Spotify::Session::OnProcessThreadEvents()
 
    if(m_ProcessEvents)
    {
-       QTimer::singleShot(next_timeout,this,SLOT(OnProcessThreadEvents()));
+       //QTimer::singleShot(next_timeout,this,SLOT(OnProcessThreadEvents()));
+       m_pProcEvtTimer->start(next_timeout);
    }
 }
 
@@ -321,9 +339,10 @@ Spotify::Error Spotify::Session::play( Spotify::Track* track, bool preBuffer )
             m_pAudioThread->setBufferingPaused(false);
             m_pAudioThread->setPlaybackPaused(false);
             m_pAudioThread->setEndOfTrack(false);
-            //m_pAudioThread->setNextTrackStartPos(-1);
-            //qApp->removePostedEvents(this);
+            m_pAudioThread->setNewTrackStarted(false);
+            m_pAudioThread->setNextTrackStartPos(-1);
             m_pAudioThread->getMutex()->unlock();
+            m_bufferPosList.clear();
         }
     }
 
@@ -480,22 +499,34 @@ Spotify::Error Spotify::Session::getPlaylists()
  m_ProcessEvents = false;
  m_DisableNotifyThread = true;
 
+ m_bPlaylistsLoading = true;
+
   for (int i=0; i < sp_playlistcontainer_num_playlists(m_playlistcontainer); i++)
   {
     sp_playlist* pl = sp_playlistcontainer_playlist(m_playlistcontainer, i);
 
    int next_timeout = -1;
+
    while(!sp_playlist_is_loaded(pl))
     { //process main app event loop while waiting for playlist to load
+       if(m_bStopPlaylistLoading)
+           break;
        sp_session_process_events(m_session,&next_timeout);
        qApp->processEvents();
-       sleep.wait(&mutex,100); //sleep for 100ms
+       sleep.wait(&mutex,100); //sleep for 100ms just in case that we would have problem with retrieving the last element in the associated list.
     }
 
-   qDebug() << "Adding playlist: " << sp_playlist_name(pl);
-   Spotify::Playlist* playlist = new Spotify::Playlist(pl,this);
-   m_playlistList.insert(i,playlist);
-  }
+   if(m_bStopPlaylistLoading)
+       break;
+
+   if(i>=m_playlistList.size())
+   {
+       qDebug() << "Adding playlist: " << sp_playlist_name(pl);
+       Spotify::Playlist* playlist = new Spotify::Playlist(pl,this);
+       m_playlistList.insert(i,playlist); //we could add the following element to the list elements in case of unsupported commands
+   }
+}
+  m_bPlaylistsLoading = false; //indicate that playlist loading done (successfully)
 
   emit playlistContainersReady(m_playlistList);
 
@@ -504,6 +535,12 @@ Spotify::Error Spotify::Session::getPlaylists()
   return error;
 }
 
+void Spotify::Session::stopPlaylistLoading()
+{
+    //set flag for requesting playlist loading to be interrupted.
+    m_bStopPlaylistLoading = true;
+}
+
 Spotify::Error Spotify::Session::getPlaylistTracks(Spotify::Playlist* pPlaylist)
 {
 	//get / update tracks for the specified playlist
@@ -1207,14 +1244,13 @@ void Spotify::Session::notifyMainThreadCallback( sp_session* session )
 
 void Spotify::Session::notifyMainThreadWrapper()
 {
-    //notification to wake up main thread
+    //notification to wake up main thread.
 
    if(!m_DisableNotifyThread)
     {
         m_ProcessEvents = true;
         emit onNotifyMainThread();
     }
-
 }
 
 int Spotify::Session::musicDeliveryCallback( sp_session* session, const sp_audioformat* format,
